@@ -28,7 +28,7 @@ DOC_SYNTAX_ERR = """def hello()
 @contextlib.contextmanager
 def temp_document(doc_text, workspace):
     try:
-        with tempfile.NamedTemporaryFile(mode='w', delete=False) as temp_file:
+        with tempfile.NamedTemporaryFile(mode="w", delete=False) as temp_file:
             name = temp_file.name
             temp_file.write(doc_text)
         yield Document(uris.from_fs_path(name), workspace)
@@ -37,7 +37,7 @@ def temp_document(doc_text, workspace):
 
 
 def write_temp_doc(document, contents):
-    with open(document.path, 'w', encoding='utf-8') as temp_file:
+    with open(document.path, "w", encoding="utf-8") as temp_file:
         temp_file.write(contents)
 
 
@@ -45,46 +45,50 @@ def test_pylint(config, workspace):
     with temp_document(DOC, workspace) as doc:
         diags = pylint_lint.pylsp_lint(config, workspace, doc, True)
 
-        msg = '[unused-import] Unused import sys'
-        unused_import = [d for d in diags if d['message'] == msg][0]
+        msg = "[unused-import] Unused import sys"
+        unused_import = [d for d in diags if d["message"] == msg][0]
 
-        assert unused_import['range']['start'] == {'line': 0, 'character': 0}
-        assert unused_import['severity'] == lsp.DiagnosticSeverity.Warning
-        assert unused_import['tags'] == [lsp.DiagnosticTag.Unnecessary]
+        assert unused_import["range"]["start"] == {"line": 0, "character": 0}
+        assert unused_import["severity"] == lsp.DiagnosticSeverity.Warning
+        assert unused_import["tags"] == [lsp.DiagnosticTag.Unnecessary]
 
         # test running pylint in stdin
-        config.plugin_settings('pylint')['executable'] = 'pylint'
+        config.plugin_settings("pylint")["executable"] = "pylint"
         diags = pylint_lint.pylsp_lint(config, workspace, doc, True)
 
-        msg = 'Unused import sys (unused-import)'
-        unused_import = [d for d in diags if d['message'] == msg][0]
+        msg = "Unused import sys (unused-import)"
+        unused_import = [d for d in diags if d["message"] == msg][0]
 
-        assert unused_import['range']['start'] == {
-            'line': 0,
-            'character': 0,
+        assert unused_import["range"]["start"] == {
+            "line": 0,
+            "character": 0,
         }
-        assert unused_import['severity'] == lsp.DiagnosticSeverity.Warning
+        assert unused_import["severity"] == lsp.DiagnosticSeverity.Warning
 
 
 def test_syntax_error_pylint(config, workspace):
     with temp_document(DOC_SYNTAX_ERR, workspace) as doc:
         diag = pylint_lint.pylsp_lint(config, workspace, doc, True)[0]
 
-        assert diag['message'].startswith("[syntax-error]")
-        assert diag['message'].count("expected ':'") or diag['message'].count('invalid syntax')
+        assert diag["message"].startswith("[syntax-error]")
+        assert diag["message"].count("expected ':'") or diag["message"].count(
+            "invalid syntax"
+        )
         # Pylint doesn't give column numbers for invalid syntax.
-        assert diag['range']['start'] == {'line': 0, 'character': 12}
-        assert diag['severity'] == lsp.DiagnosticSeverity.Error
-        assert 'tags' not in diag
+        assert diag["range"]["start"] == {"line": 0, "character": 12}
+        assert diag["severity"] == lsp.DiagnosticSeverity.Error
+        assert "tags" not in diag
 
         # test running pylint in stdin
-        config.plugin_settings('pylint')['executable'] = 'pylint'
+        config.plugin_settings("pylint")["executable"] = "pylint"
         diag = pylint_lint.pylsp_lint(config, workspace, doc, True)[0]
 
-        assert diag['message'].count("expected ':'") or diag['message'].count('invalid syntax')
+        assert diag["message"].count("expected ':'") or diag["message"].count(
+            "invalid syntax"
+        )
         # Pylint doesn't give column numbers for invalid syntax.
-        assert diag['range']['start'] == {'line': 0, 'character': 12}
-        assert diag['severity'] == lsp.DiagnosticSeverity.Error
+        assert diag["range"]["start"] == {"line": 0, "character": 12}
+        assert diag["severity"] == lsp.DiagnosticSeverity.Error
 
 
 def test_lint_free_pylint(config, workspace):
@@ -93,7 +97,8 @@ def test_lint_free_pylint(config, workspace):
     # though, so it works for a test of an empty lint.
     ws = Workspace(str(Path(__file__).absolute().parents[2]), workspace._endpoint)
     assert not pylint_lint.pylsp_lint(
-        config, ws, Document(uris.from_fs_path(__file__), ws), True)
+        config, ws, Document(uris.from_fs_path(__file__), ws), True
+    )
 
 
 def test_lint_caching(workspace):
@@ -106,7 +111,7 @@ def test_lint_caching(workspace):
     # need to ensure that pylint doesn't give us invalid-name when our temp
     # file has capital letters in its name.
 
-    flags = '--disable=invalid-name'
+    flags = "--disable=invalid-name"
     with temp_document(DOC, workspace) as doc:
         # Start with a file with errors.
         diags = pylint_lint.PylintLinter.lint(doc, True, flags)
@@ -114,7 +119,7 @@ def test_lint_caching(workspace):
 
         # Fix lint errors and write the changes to disk. Run the linter in the
         # in-memory mode to check the cached diagnostic behavior.
-        write_temp_doc(doc, '')
+        write_temp_doc(doc, "")
         assert pylint_lint.PylintLinter.lint(doc, False, flags) == diags
 
         # Now check the on-disk behavior.
@@ -130,4 +135,5 @@ def test_per_file_caching(config, workspace):
         assert pylint_lint.pylsp_lint(config, workspace, doc, True)
 
     assert not pylint_lint.pylsp_lint(
-        config, workspace, Document(uris.from_fs_path(__file__), workspace), False)
+        config, workspace, Document(uris.from_fs_path(__file__), workspace), False
+    )
